@@ -1,21 +1,33 @@
 "wgts" <-
-  function(weight, cl, mat, K) {
+  function(weight, cl, mat, K, zero) {
+    # Fix category zero problem
+    if (zero == TRUE) {
+      R <- row(mat) - 1
+      C <- col(mat) - 1
+    } else{
+      R <- row(mat)
+      C <- col(mat)
+    }
+    
+    # Compute weights
     if (is.numeric(weight)) {
       w <- weight
     } else if (any(grepl("^quadratic$", weight))) {
-      w <- 1 - (abs(row(mat) - col(mat)) / (K - 1)) ^ 2
+      w <- 1 - (abs(R - C) / (K - 1)) ^ 2
     } else if (any(grepl("^linear$", weight))) {
-      w <- 1 - (abs(row(mat) - col(mat)) / (K - 1))
+      w <- 1 - (abs(R - C) / (K - 1))
     } else  if (any(grepl("^unweighted$", weight))) {
       w <- diag(K)
-    } else  if (any(grepl("^ratio$", weight)) && any(grepl("kra", cl))) {
-      w <- ((row(mat) - col(mat)) / (row(mat) + col(mat))) ^ 2
-    } else if (any(grepl("^ratio$", weight)) && any(grepl("gac", cl))) {
+    } else  if (any(grepl("^ratio$", weight)) &&
+                any(grepl("kra", cl))) {
+      w <- ((R - C) / (R + C)) ^ 2
+    } else if (any(grepl("^ratio$", weight)) &&
+               any(grepl("gac", cl))) {
       w <-
-        1 - ((row(mat) - col(mat)) / (row(mat) + col(mat))) ^ 2 / ((K - 1) / (K +
-                                                                                1)) ^ 2
+        1 - ((R - C) / (R + C)) ^ 2 / ((K - 1) / (K +
+                                                    1)) ^ 2
     } else  if (any(grepl("^interval$", weight))) {
-      w <- (row(mat) - col(mat)) ^ 2
+      w <- (R - C) ^ 2
     } else  if (any(grepl("^ordinal$", weight))) {
       w <- matrix(0, K, K)
       for (i in 2:(K - 1)) {
@@ -32,12 +44,4 @@
     
     return(w)
     
-  }
-
-
-
-
-
-
-
-
+  }
\ No newline at end of file
